#
# spec file for package incus
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%go_nostrip

%define _buildshell /bin/bash
%define import_path github.com/lxc/incus

# We need OVMF in order to support VMs with Incus.
%ifarch x86_64 aarch64
%define arch_vm_support 1
%else
%define arch_vm_support 0
%endif

Name:           incus
Version:        6.11
%define tag_version 6.11.0
Release:        1.1
Summary:        Container hypervisor based on LXC
License:        Apache-2.0
Group:          System/Management
URL:            https://linuxcontainers.org/incus/
Source:         https://github.com/lxc/%{name}/releases/download/v%{tag_version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxc/%{name}/releases/download/v%{tag_version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        %{name}-rpmlintrc
Source4:        %{name}.sysusers
# Based on <https://github.com/zabbly/incus/tree/stable/systemd>.
Source100:      incusd
Source101:      %{name}.service
Source102:      %{name}.socket
Source103:      sysconfig.%{name}
Source111:      %{name}-user.service
Source112:      %{name}-user.socket
Source113:      sysconfig.%{name}-user
Source120:      %{name}-startup
Source121:      %{name}-startup.service
# Incus upstream doesn't have a sample config file.
Source130:      %{name}-config.yml
# Additional runtime configuration.
Source201:      %{name}.dnsmasq
BuildRequires:  fdupes
BuildRequires:  file
BuildRequires:  go >= 1.22.7
BuildRequires:  golang-packaging
BuildRequires:  libacl-devel
BuildRequires:  libcap-devel
BuildRequires:  liblz4-devel
BuildRequires:  patchelf
BuildRequires:  pkgconfig
BuildRequires:  rsync
BuildRequires:  sqlite3-devel >= 3.25
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(cowsql)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(lxc) >= 5.0.0
# For completion directories.
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  zsh
Requires:       kernel-base >= 5.4
# Bits required for images and other things at runtime.
Requires:       acl
Requires:       attr
Requires:       ebtables
BuildRequires:  dnsmasq
Requires:       dnsmasq
Requires:       lego
Requires:       lxcfs
Requires:       lxcfs-hooks-lxc
Requires:       rsync
Requires:       squashfs
Requires:       tar
Requires:       xz
%if 0%{arch_vm_support} != 0
# Needed for VM support.
%ifarch x86_64
Requires:       lxd-ovmf-setup-x86_64
%endif
%ifarch aarch64
Requires:       lxd-ovmf-setup-aarch64
%endif
Requires:       qemu-chardev-spice
Requires:       qemu-hw-display-virtio-gpu
Requires:       qemu-hw-display-virtio-vga
Requires:       qemu-hw-usb-redirect
Requires:       qemu-img
Requires:       qemu-spice
Requires:       virtiofsd
# QEMU spice became a separate package for QEMU 5.2, which is not in Leap 15.2.
# But it exists in Tumbleweed so only require this in Tumbleweed.
%if 0%{?suse_version} > 1500 || 0%{?sle_version} == 150300
Requires:       qemu-ui-spice-core
%else
Requires:       qemu-ui-spice-app
%endif
# TODO: Should we enable non-native VMs by default?
%ifarch %ix86 x86_64
Requires:       qemu-x86 >= 6.0
%endif
%ifarch aarch64 %arm
Requires:       qemu-arm >= 6.0
%endif
%endif
# Needed for OCI support.
Requires:       skopeo
Requires:       umoci
# Helper tools for admins.
Recommends:     %{name}-tools
# Storage backends -- we don't recommend ZFS since it's not *technically* a
# blessed configuration.
Recommends:     lvm2
Recommends:     btrfsprogs
Recommends:     thin-provisioning-tools
# CRIU is used for certain operations but is not necessary (and is no longer
# shipped on 32-bit openSUSE).
Recommends:     criu >= 2.0
Suggests:       zfs
%sysusers_requires

%description
Incus is a system container manager. It offers a user experience
similar to virtual machines but uses Linux containers (LXC) instead.

%package tools
Summary:        Optional extra tools for %{name}
Group:          System/Management
Requires:       %{name} = %{version}

%description tools
Extra tools to help with the administration of Incus. This includes helpers for
migrating from LXD to Incus as well as a smattering of other helpers that can
be helpful for some users but are not necessary for most Incus deployments
(such as benchmarking tools and tools for managing simplestreams Incus image
servers).

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -p1

%build
%sysusers_generate_pre %{SOURCE4} %{name} %{name}.conf

# Make sure any leftover go build caches are gone.
go clean -cache

# Find all of the main packages using go-list.
readarray -t mainpkgs \
	<<<"$(go list -f '{{.Name}}:{{.ImportPath}}' %{import_path}/... | \
	      awk -F: '$1 == "main" { print $2 }' | \
	      grep -E '^github.com/lxc/incus/(v.*/)?cmd/')"

# Needed because incus and deps use funky #cgo LDFLAGS that Go blocks by default.
export CGO_LDFLAGS_ALLOW="(-Wl,-wrap,pthread_create)|(-Wl,-z,now)"

# The upstream Makefile uses "go install" which doesn't work for packaging.
mkdir bin
for mainpkg in "${mainpkgs[@]}"
do
	# Make sure all binaries contain "incus" somewhere in their name.
	binary="$(basename "$mainpkg")"
	if  ( echo "$binary" | grep -Eqv '%{name}' )
	then
		binary="%{name}-$binary"
	fi
	case "$binary" in
	incus-agent)
		build_static=1
		build_tags="agent,netgo"
		;;
	incus-migrate)
		build_static=1
		build_tags="netgo"
		;;
	*)
		build_static=
		build_tags="libsqlite3"
		;;
	esac
	(
		if [ -n "$build_static" ]
		then
			CGO_ENABLED=0 go build -ldflags "-extldflags -static" \
				-tags "$build_tags" -o "bin/$binary" "$mainpkg"
		else
			go build -buildmode=pie \
				-tags "$build_tags" -o "bin/$binary" "$mainpkg"
		fi
	)
done

# Replace /usr/libexec in our sources with the proper directory. This is needed
# because Leap 15.x still uses /usr/lib while Tumbleweed uses /usr/libexec. See
# <https://en.opensuse.org/openSUSE:Specfile_guidelines#Libexecdir> for more
# details.
readarray -t sourcefiles <<<"$(find "%{_sourcedir}" -type f)"
for sourcefile in "${sourcefiles[@]}"
do
	[[ "$(file -b --mime-encoding "$sourcefile")" == "binary" ]] && continue
	sed -i 's|/usr/libexec|%{_libexecdir}|g' "$sourcefile"
done

# Generate man pages.
mkdir man
./bin/incus manpage man/

# Generate completion scripts.
mkdir -p scripts/completion
for sh in bash zsh fish
do
	./bin/incus completion $sh >scripts/completion/incus.$sh
done

# Final sanity-check during build.
pushd bin/
for bin in *
do
	# Ensure that all our binaries are dynamic (except for incus-agent, which
	# must be static). boo#1138769
	case "$(basename $bin)" in
	incus-agent | incus-migrate)
		file "$bin" | grep 'statically linked'
		;;
	*)
		file "$bin" | grep 'dynamically linked'
		# Check what they are linked against.
		ldd "$bin"
		;;
	esac
done
popd

# Drop the html docs and build-related docs as they are mostly duplicates of
# the markdown docs and give us a bad rpmlint score.
rm -rf doc/{html/,.{sphinx,.wordlist.txt}}

%install
# Install all the binaries.
pushd bin/
for bin in *
do
	case "$bin" in
	incus-user | lxd-to-incus | incus-fuidshift | incus-migrate)
		# - incus-user is only ever run by systemd as root.
		# - lxd-to-incus needs to be run as root to configure everything.
		# - fuidshift is only used by admins to fixup a broken rootfs.
		# - incus-migrate requires root access to scan the host.
		bindir="%{_sbindir}"
		;;
	incusd)
		# Our /usr/sbin/incusd is a wrapper around /usr/libexec/incus/incsud to
		# set some environment variables.
		bindir="%{_libexecdir}/%{name}"
		;;
	incus-agent)
		# incus-agent is only used internally by incus, and is a binary that
		# gets inserted into containers so it isn't even run on the host.
		bindir="%{_libexecdir}/%{name}"
		;;
	*)
		bindir="%{_bindir}"
		;;
	esac
	install -D -m 0755 "$bin" "%{buildroot}$bindir/$bin"
done
popd

# System-wide client configuration.
install -D -m0644 %{S:130} %{buildroot}/etc/incus/config.yml
install -d -m0755 %{buildroot}/etc/incus/servercerts

# Install man pages.
pushd man/
for man in *
do
	section="${man##*.}"
	install -D -m 0644 "$man" "%{buildroot}%{_mandir}/man$section/$man"
done
popd

# *sh-completion
install -D -m 0644 scripts/completion/incus.bash %{buildroot}%{_datarootdir}/bash-completion/completions/incus
install -D -m 0644 scripts/completion/incus.fish %{buildroot}/%{_datadir}/fish/vendor_completions.d/incus.fish
install -D -m 0644 scripts/completion/incus.bash %{buildroot}%{_sysconfdir}/zsh_completion.d/_incus

# systemd
install -D -m 0755 %{S:100} %{buildroot}%{_sbindir}/incusd
install -D -m 0644 %{S:101} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 %{S:102} %{buildroot}%{_unitdir}/%{name}.socket
install -D -m 0644 %{S:111} %{buildroot}%{_unitdir}/%{name}-user.service
install -D -m 0644 %{S:112} %{buildroot}%{_unitdir}/%{name}-user.socket

# sysconfig files
install -D -m 0644 %{S:103} %{buildroot}%{_fillupdir}/sysconfig.%{name}
install -D -m 0644 %{S:113} %{buildroot}%{_fillupdir}/sysconfig.%{name}-user

# incus-startup
install -D -m 0755 %{S:120} %{buildroot}%{_libexecdir}/%{name}/%{name}-startup
install -D -m 0644 %{S:121} %{buildroot}%{_unitdir}/%{name}-startup.service

# sysv-init
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-user

# Run-time configuration.
install -D -m 0644 %{S:201} %{buildroot}%{_sysconfdir}/dnsmasq.d/60-incus.conf

# Run-time directories.
install -d -m 0711 %{buildroot}%{_localstatedir}/lib/%{name}
install -d -m 0755 %{buildroot}%{_localstatedir}/log/%{name}

# sysusers.d
install -D -m 0644 %{SOURCE4} %{buildroot}%{_sysusersdir}/%{name}.conf

%fdupes %{buildroot}

%pre -f %{name}.pre

# /etc/sub[ug]id should exist already (it's part of shadow-utils), but older
# distros don't have it. Incus just parses it and doesn't need any special
# shadow-utils helpers.
touch /etc/subuid /etc/subgid ||:

# Add sub[ug]ids for Incus's unprivileged containers -- in order to support
# isolated containers we add quite a few subuids. Since Incus runs as root we add
# them for the root user (not the incus-admin group). We only bother if there
# aren't any mappings available already.
#
# We have no guarantee that the range we pick will be unique -- which ideally
# we would want it to be. There isn't a nice way to do this without
# reimplementing a bunch of range-handling code for /etc/sub[ug]id in bash. So
# we just pick the 400-900 million range, and hope for the best (most tutorials
# use the 1-million range, so we avoid that pitfall).
#
# This default setting of 500 million is enough for ~8000 isolated containers,
# which should be enough for most users.
grep -q '^root:' /etc/subuid || \
	usermod -v 400000000-900000000 root &>/dev/null || \
	echo "root:400000000:500000001" >>/etc/subuid ||:
grep -q '^root:' /etc/subgid || \
	usermod -w 400000000-900000000 root &>/dev/null || \
	echo "root:400000000:500000001" >>/etc/subgid ||:

%service_add_pre %{name}.service %{name}.socket
%service_add_pre %{name}-startup.service
%service_add_pre %{name}-user.service %{name}-user.socket

%post
%service_add_post %{name}.service %{name}.socket
%service_add_post %{name}-startup.service
%fillup_only -n %{name}

%service_add_post %{name}-user.service %{name}-user.socket
%fillup_only -n %{name}-user

%preun
%service_del_preun %{name}.service %{name}.socket
%service_del_preun %{name}-startup.service
%service_del_preun %{name}-user.service %{name}-user.socket

%postun
%service_del_postun %{name}.service %{name}.socket
%service_del_postun %{name}-startup.service
%service_del_postun %{name}-user.service %{name}-user.socket

%files
%defattr(-,root,root)
%doc AUTHORS README.md doc/
%license COPYING
%{_bindir}/incus
%{_sbindir}/incusd
%{_sbindir}/incus-user
%{_mandir}/man*/*

%dir /etc/incus
%config(noreplace) /etc/incus/config.yml
%dir /etc/incus/servercerts

%{_libexecdir}/%{name}/
%{_sbindir}/rc%{name}*
%{_unitdir}/%{name}*.service
%{_unitdir}/%{name}*.socket

%{_sysusersdir}/%{name}.conf
%{_fillupdir}/sysconfig.%{name}*

%dir %{_localstatedir}/lib/%{name}
%dir %{_localstatedir}/log/%{name}

%config(noreplace) %{_sysconfdir}/dnsmasq.d/60-incus.conf

%files tools
%defattr(-,root,root)
%{_bindir}/incus-benchmark
%{_bindir}/incus-simplestreams
%{_bindir}/incus-generate-config
%{_bindir}/incus-generate-database
%{_bindir}/lxc-to-incus
%{_sbindir}/incus-fuidshift
%{_sbindir}/incus-migrate
%{_sbindir}/lxd-to-incus

%files bash-completion
%defattr(-,root,root)
%{_datarootdir}/bash-completion/completions/incus

%files fish-completion
%defattr(-,root,root)
%{_datadir}/fish/vendor_completions.d/incus.fish

%files zsh-completion
%defattr(-,root,root)
%{_sysconfdir}/zsh_completion.d/_incus

%changelog
* Mon Apr 14 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 6.11:
  * Allow ICMP and low ports for unprivileged users in OCI containers by @gwenya in #1706
  * doc: Clarify virtiofsd requirements by @stgraber in #1718
  * Fix generate-database usage for incusd/db by @breml in #1719
  * Do not allow mounting of custom block volume snapshots by @presztak in #1720
  * generate-database: Abstract db connection / db transaction by @breml in #1721
  * Fix snapshot size handling in cross-pool copy/move by @presztak in #1717
  * generate-database: Accept interface in PrepareStmts by @breml in #1725
  * Simplify evaluateShorthandFilter by reducing nesting levels by @presztak in #1727
  * incusd/storage: Don't use sparse writer on thick LVM by @stgraber in #1729
  * generate-database: Add support for marshal to JSON by @breml in #1731
  * Fixed incus edk2 path overwrite issue by @nanjj in #1726
  * Do not download instance types if cache loadable by @nanjj in #1732
  * Clarify security.secureboot setting by @gwenya in #1740
  * Fix DNS for isolated OVN networks by @gwenya in #1738
  * Allow announcing extra routes through DHCPv4 by @gwenya in #1734
  * Fix link parsing failure on non-ethernet devices by @stgraber in #1742
  * Fix revert on OCI container creation failure by @gwenya in #1744
  * generate-database: Handle non tx DB connections by @breml in #1745
  * incus file edit extension by @gwenya in #1746
  * Cleanup internal API endpoints by @stgraber in #1747
  * Tweak help message for rebuild by @stgraber in #1754
  * Use lego binary for DNS-01 challenge by @accuser in #1753
  * incusd/storage/zfs: Fix ZFS CreateVolume deletes pre-existing data on failure by @mrstux in #1749
  * incus/file: Always use 1MB chunks for SFTP by @stgraber in #1758
  * Use the correct path for ingesting DNS-01 challenge certificate outputs by @accuser in #1759
  * incusd/bgp: Rework start/stop logic by @stgraber in #1761
  * incusd/network/ovn: Skip existing static routes by @stgraber in #1762
  * incusd/instance/qemu: Set caching-mode with intel-iommu by @stgraber in #1772
  * incus-agent: Improve SFTP performance by @stgraber in #1773
  * incusd/network/ovn: Keep getting router name when network none by @diegofernandes in #1771
  * make incus copy --device xx,type=none drop remaining device properties by @schnoddelbotz in #1764
  * incusd/instance/qemu: rtc base localtime for windows by @nanjj in #1767
  * Add option to configure DNS server for bridge and OVN networks by @gwenya in #1739
  * Use lego binary for http 01 challenge by @accuser in #1770
  * Handle live migration between QEMU versions by @stgraber in #1775
  * incusd/instance/qemu: Skip to link nvram to itself by @nanjj in #1760
  * Switch to new MAC address prefix by @stgraber in #1776
  * client: Fix spelling errors found by codespell by @cjwatson in #1777
  * Add ipv4.dhcp.expiry option for ovn networks by @gwenya in #1781
  * Configure DHCP on existing instance interfaces when it is enabled on a network by @gwenya in #1780
  * incusd/instance/edk2: Select SecureBoot capable firmware on Debian by @stgraber in #1782
  * Fix some go  vet warnings by @stgraber in #1784
  * Clear gofumpt by @stgraber in #1803
  * Fix some BGP issues by @stgraber in #1805
  * incusd/instance/qemu: bad pid check by @nanjj in #1806
  * Fix spelling errors and run codespell automatically by @cjwatson in #1778
  * incus/file: Properly handle relative source paths by @stgraber in #1809
  * cmd/storage: incorrect CLI syntax in storage pool creation examples by @ViniRodrig in #1810
  * Improve DB performance by @stgraber in #1811
  * incusd/network/ovn: Fix default DNS IPv4 server by @stgraber in #1812
  * Extend OS detection logic by @stgraber in #1813
  * Add allocated CPU time to instance state by @bensmrs in #1807
  * incusd/certificates: Properly handle bad PEM data by @stgraber in #1816
  * Extra generate-database features by @masnax in #1817
  * incusd/network/common: Handle missing BGP peer by @stgraber in #1818
  * incusd/cluster/evacuate: Don't live-migrate stopped instances by @stgraber in #1819
  * Fix generator table pluralization by @masnax in #1823
  * incusd/instance/qemu enable s4 by default by @nanjj in #1820
  * Add support for USB NICs by @bensmrs in #1814
  * incusd/storage/s3 Fixed minio client mc too ambious issue by @nanjj in #1821
  * incusd/networks: Validate configuration on join too by @stgraber in #1824
  * Update gomod for go-jwt vulnerability by @stgraber in #1825
  * cmd/generate-database/db: Fix GetNames spacing by @masnax in #1826
  * github: Rework issue templates by @stgraber in #1827
  * Update Debian installation documentation by @gibmat in #1830
  * Extend minio client naming by @gibmat in #1829
  * Various fixes from address set PR by @stgraber in #1831
  * incusd/instance/lxc: Cleanup OCI mount paths by @stgraber in #1834
  * Add io.bus=usb for disks by @bensmrs in #1835
  * golangci: Upgrade to version 2 by @stgraber in #1836
  * golangci: Disable STI005 error checks by @stgraber in #1841
  * Standalone changes from the Linstor branch by @stgraber in #1842
  * incusd/storage/s3 minio client check enhancement by @nanjj in #1839
  * incusd/network/ovn: Remove internal routes to forward/load-balancers by @stgraber in #1843
  * incusd/instance/edk2: Always prefer the EDK2 override by @stgraber in #1847
  * Fixes from Linstor branch by @stgraber in #1846
  * Add linstor storage driver by @luissimas in #1621
  * Add linstor.remove_snapshots config option by @luissimas in #1848
  * doc/support: Update feature release version by @bensmrs in #1853
  * incusd/instance: Don't enforce device/config validation on snapshots by @stgraber in #1854
  * OCI entrypoint configuration by @gwenya in #1845
- update to 6.10.1:
  * incusd/network/bridge: Fix deletion of tunnels and dummy devices by @montag451 in #1698
  * Translations update from Hosted Weblate by @weblate in #1710
  * Provide the RBD keeyring to QEMU by @stgraber in #1709
  * incusd/storage/ceph: Re-introduce keyring parsing by @stgraber in #1716
  * Move IOMMU handling under configuration option by @stgraber in #1715
- update to 6.10:
  * incusd/instance/drivers/qmp: Handle missing log directory by @stgraber in #1604
  * incus-user: keep track of socket path used to connect to the server by @bboozzoo in #1607
  * incus-user: unify logging, support --verbose and --debug by @bboozzoo in #1606
  * Add project support to profiles in preseed init by @megheaiulian in #1608
  * incusd/network/ovn: Fix bad route check by @stgraber in #1616
  * incus/file/pull: Ensure we have a leading / in all paths by @stgraber in #1617
  * incus/file/pull: Read files in chunks by @stgraber in #1623
  * doc/installing: mention incus group on NixOS by @dawidd6 in #1622
  * incus/file/pull: Actually make read buffer 1MiB by @stgraber in #1624
  * Translations update from Hosted Weblate by @weblate in #1639
  * incusd/device/disk: Allow virtiofsd on non-x86 by @stgraber in #1638
  * Translations update from Hosted Weblate by @weblate in #1640
  * Translations update from Hosted Weblate by @weblate in #1642
  * incusd/instance/drivers/qemu: Add IOMMU device by @stgraber in #1644
  * incus/file: Remove unused function by @stgraber in #1645
  * Translations update from Hosted Weblate by @weblate in #1646
  * incus/network/info (ovn): Fix object not found. by @rxtom in #1628
  * incusd/instance/drivers: Improve NUMA balancing by @lnutimura in #1626
  * incusd/network/bridge: Fix deletion of tunnels and dummy devices by @montag451 in #1627
  * incus/file: Move from path to filepath by @stgraber in #1647
  * Added LZ4 support for incus import by @Spitfireap in #1611
  * Add vrf parameter for routed-nic devices by @ibot3 in #1615
  * Translations update from Hosted Weblate by @weblate in #1648
  * Translations update from Hosted Weblate by @weblate in #1651
  * Move generators to the cmd package by @stgraber in #1652
  * Fix incorrect volume group naming when vg_name is not specified by @presztak in #1653
  * Rename incus-generate and incus-doc by @breml in #1654
  * Implement smbios11 config keys by @stgraber in #1655
  * Fix instance copy error when using '--refresh' flag by @presztak in #1658
  * Fix docs for load balancer create backend by @gwenya in #1661
  * incusd/instance/utils: Only check uid/gid for containers by @stgraber in #1662
  * incusd/main_nsexec: Fix change_namespaces fallback to handle multiple… by @stgraber in #1664
  * Check if disk is remote when migrating with an extra disk by @presztak in #1669
  * incusd/instance/edk2: Look for bios.bin in /usr/share/seabios by @stgraber in #1672
  * Replace ast.Package with types.Package by @breml in #1665
  * list/format: provide more information on error by @rxtom in #1666
  * Add additional validation when joining a new cluster member by @presztak in #1680
  * Upgrade flosch/pongo2 to v6 by @nanjj in #1677
  * incusd/resources: Prevent concurrent runs and cache data for 10s by @stgraber in #1681
  * Fix importing from older backups by @stgraber in #1683
  * fix: Don't attempt to download signatures for oci by @m2Giles in #1685
  * Ensure directories have 755 permissions in incus file push -p command by @presztak in #1687
  * devcontainer: Update Go to 1.23 by @breml in #1689
  * Make "Code generated" comments for generate-database Go conformant by @breml in #1690
  * Disclaimer internal tool for generate-database and generate-config by @breml in #1694
  * Truncate the block file during custom volume migration by @presztak in #1696
  * Rework virtiofsd uid/gid map handling by @stgraber in #1692
  * Remove unused arguments and parameters by @presztak in #1699
  * generate-database: Use deferred func to map errors & make generated code self-sufficient by @breml in #1695
  * incus/top: Fix handling of all-projects by @stgraber in #1701
  * Ceph refactor by @MadnessASAP in #1538
  * incus/file: Port remaining functions to SFTP by @HassanAlsamahi in #1649
  * Add filtering to all API collections by @gwenya in #1679
  * Add provider for DNS-01 ACME challenge by @accuser in #1668
* Sat Jan 25 2025 Maciej Borzecki <maciek.borzecki@gmail.com>
- update to 6.9:
  * Translations update from Hosted Weblate by @weblate in #1506
  * Refactor scriptlet loader and improve checks by @bensmrs in #1507
  * Translations update from Hosted Weblate by @weblate in #1511
  * incusd/storage/drivers: Force blkdiscard and ignore errors by @stgraber in #1513
  * incusd/auth: fix FGA online data race by @breml in #1515
  * incusd/storage/drivers: Log on blkdiscard failure by @stgraber in #1517
  * Fix issue with live-migration between storage pools by @presztak in #1518
  * Add uplink addresses for OVN network by @winiciusallan in #1512
  * Add --description flag to create type CLI commands by @luissimas in #1498
  * client: Propagate HTTP TLS dialer to websocket by @stgraber in #1519
  * Fix QEMU scriptlet parameter name by @bensmrs in #1524
  * Add shell.nix by @MadnessASAP in #1526
  * client: add proxy host to skopoe inspect by @winiciusallan in #1525
  * incusd/cluster: Add missing error handling by @stgraber in #1528
  * incusd/instance/qemu: Fix QMP arguments typing by @bensmrs in #1531
  * Encode mc alias for storage buckets to match allowed characters by @monkz in #1535
  * doc: Contributing section restructuring by @bensmrs in #1534
  * internal/server: allow creation of OVN network with no uplink by @winiciusallan in #1533
  * Translations update from Hosted Weblate by @weblate in #1540
  * Translations update from Hosted Weblate by @weblate in #1541
  * lxd-to-incus: Clear volatile.uuid from instances by @stgraber in #1546
  * Translations update from Hosted Weblate by @weblate in #1548
  * Translations update from Hosted Weblate by @weblate in #1550
  * Translations update from Hosted Weblate by @weblate in #1551
  * Translations update from Hosted Weblate by @weblate in #1553
  * Tweak Github Actions and add arm64 tests by @stgraber in #1555
  * Translations update from Hosted Weblate by @weblate in #1556
  * incusd/networks: Tweak dnsmasq startup condition by @alex14641 in #1544
  * Tweak namespace attach logic in forkproxy and forkfile by @stgraber in #1557
  * Expand block reset logic by @stgraber in #1560
  * Discard blocks on LVM resize by @stgraber in #1561
  * incusd/storage/lvm: Run ClearBlock on all new thick block volumes by @stgraber in #1565
  * Improve format flag by @breml in #1564
  * devcontainer: initial version by @breml in #1566
  * incusd/network/ovn: Skip remote peers when iterating peer networks by @stgraber in #1568
  * Fix discard logic on LVM resize and optimize image unpacking by @stgraber in #1569
  * incusd/main_cluster: Tweak to have help refer to correct command name by @stgraber in #1576
  * Docs: Fixed link to point to correct manpage. by @foxtrotcz in #1581
  * incusd/device/disk: Better handle partitions by @stgraber in #1578
  * incusd/storage/drivers: Handle 4k sector sizes by @stgraber in #1585
  * lxd-to-incus: Be more lenient on database changes by @stgraber in #1582
  * incusd/dnsmasq: Don't put the project name in the DNS record by @stgraber in #1586
  * Remove virtfs-proxy-helper dependency by @bensmrs in #1547
  * Add new config hook by @bensmrs in #1577
  * github: Switch to Github's hosted arm64 runners by @stgraber in #1589
  * Support for ACLs for bridge NIC device when using nftables driver by @stgraber in #1587
  * doc: typo by @eebssk1 in #1591
  * Added unit for minimum ZFS blocksize by @Spitfireap in #1593
  * incus/file/pull: Port to SFTP by @HassanAlsamahi in #1592
  * incusd/device/disk: Update correct mount options by @stgraber in #1594
  * doc: Force white background for swagger API by @stgraber in #1599
  * Implement a VM memory dump API by @SpiffyEight77 in #1596
  * gomod: Update dependencies by @stgraber in #1600
  * incus/init: Add support for storage volumes in preseed init by @megheaiulian in #1595
  * incusd/instance/qemu: Fix device_id warning on 9.2.x by @stgraber in #1601
  * incus: Fix example description for debug dump-memory command by @SpiffyEight77 in #1602
* Wed Jan  8 2025 Aleksa Sarai <asarai@suse.com>
- Add missing Requires for OCI support. bsc#1234300
* Wed Dec 25 2024 Callum Farmer <gmbr3@opensuse.org>
- Migrate to single LXD/Incus OVMF handling (lxd-ovmf-setup):
  * Allow aarch64 arch_vm_support
  * Remove OVMF symlinks
  * Require the new lxd-ovmf-setup packages
* Fri Dec 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.8:
  * exec: Consume websocket pings for stderr by @stefanor in #1380
  * incus-simplestreams: Add prune command by @presztak in #1381
  * internal/instance: Fix validation of volatile.cpu.nodes by
    @stgraber in #1394
  * Add a function to clone map and use it where appropriate by
    @montag451 in #1397
  * cgo/process_utils: fix 32bit builds by @brauner in #1398
  * Start using goimports by @stgraber in #1399
  * instance/config: Mark user keys as live updatable by @stgraber
    in #1404
  * incus/internal/server/instance/drivers/: Fix incorrect Vars
    file mapping in edk2 driver by @cmspam in #1406
  * zfs: load keys for encrypted datasets during pool import by
    @cyphar in #1384
  * incusd/instance: Lock image access by @stgraber in #1408
  * incus/image: Make use of server-side alias handling by
    @stgraber in #1409
  * incusd/cluster: Validate cluster HTTPS address on join too by
    @stgraber in #1411
  * Remove metadata info from space usage calculation by @presztak
    in #1417
  * Add ability to set the initial owner of a custom volume by
    @presztak in #1415
  * Allow local live-migration between storage pools by @presztak
    in #1410
  * incus: Add aliases completion by @montag451 in #1385
  * golangci: Add local prefixes for goimports by @breml in #1401
  * client: invalidate simple streams cache by @breml in #1424
  * incusd/instances_post: Fix cluster internal migrations by
    @stgraber in #1427
  * Fix DHCP client keeping container up by @stgraber in #1430
  * Add support for VGA console screenshots by @breml in #1431
  * Add --reuse to incus image import by @presztak in #1428
  * Fix random ETag values due to map ordering by @stgraber in
    [#1432]
  * incusd/task: Fix wait group logic (more entries than running
    tasks) by @stgraber in #1433
  * Allow setting aliases during raw image upload by @stgraber in
    [#1434]
  * Fixes an issue when copying a custom volume using the --refresh
    flag by @presztak in #1437
  * Openfga improvements by @stgraber in #1435
  * doc/instance/properties: Add missing instance properties by
    @stgraber in #1439
  * incusd/daemon_storage: Ensure corect symlinks for
    images/backups by @stgraber in #1441
  * incusd/storage/lvm: Handle newer LVM by @stgraber in #1442
  * Tweak rendering of manpage in doc by @stgraber in #1443
  * incusd/storage/lvm: Require 512-bytes physical block size for
    VM images by @stgraber in #1444
  * incusd: Fill ExpiryDate and remove LastUsedDate in
    volumeSnapshotToProtobuf by @presztak in #1448
  * incusd/device/tpm: Wait for swtpm to be ready by @stgraber in
    [#1447]
  * incus: Improve completion for file push and file pull by
    @montag451 in #1445
  * incusd/auth/tls: Restrict config access to non-admin by
    @stgraber in #1451
  * incusd/storage: Handle default disk size in GetInstanceUsage by
    @stgraber in #1452
  * incus: Improve completion for some file sub-commmands by
    @montag451 in #1453
  * incus: Fix completion for profile copy by @montag451 in #1454
  * incus: Add completion for image alias subcommands by @montag451
    in #1457
  * doc/installing: Update Fedora instructions by @stgraber in
    [#1456]
  * Fix gap in validation of pre-existing certificates when
    switching to PKI mode by @stgraber in #1458
  * doc/network_forwards: Split configuration into own table by
    @stgraber in #1460
  * chore: Happy path on the left, early return by @breml in #1461
  * incus: Fix completion for image alias create by @montag451 in
    [#1459]
  * incus/top: Ignore CPU idle time by @stgraber in #1462
  * incus: Display the alias expansion when execution of an alias
    fails by @montag451 in #1464
  * lint: disallow restricted licenses in go-licenses by @breml in
    [#1466]
  * chore: code structure, Go identifier shaddowing by @breml in
    [#1465]
  * incus: Fix alias arguments handling by @montag451 in #1463
  * incus/file/push Use SFTP client instead of file API by
    @HassanAlsamahi in #1468
  * Fix TPM fd leaks and OpenFGA patching issue by @stgraber in
    [#1469]
  * Clarify device override syntax by @stgraber in #1471
  * incusd/auth/openfga: refresh model before applying patches by
    @stgraber in #1472
  * Add authorization scriptlet by @bensmrs in #1412
  * doc: add openSUSE installation instructions by @cyphar in #1475
  * OCI image debugging improvements by @danbiagini in #1478
  * Add function checks to scriptlet validation by @bensmrs in
    [#1484]
  * incus/project: Fix handling of default (unset) project in
    get-current by @irhndt in #1476
  * Translations update from Hosted Weblate by @weblate in #1492
  * Add --force flag to the console command by @presztak in #1491
  * Accept io.Writer in RenderTable by @breml in #1490
  * doc/network_bridge: Fix missing escaping around variable by
    @irhndt in #1493
  * incusd/cluster: Skip project restrictions during join by
    @stgraber in #1497
  * incusd/instance/lxc: Skip instances without idmap allocation
    yet by @stgraber in #1495
  * incusd/storage/drivers/common: Truncate/Discard ahead of sparse
    write by @stgraber in #1496
  * Add AskPassword/AskPasswordOnce to Asker by @breml in #1499
  * Add additional check to Cancel method for ConsoleShow operation
    by @presztak in #1500
  * Improve console disconnections by @stgraber in #1501
  * Fix duplicate OVN load-balancer entries by @stgraber in #1502
  * Improve SFTP performance by @stgraber in #1503
  * incusd/instance_post: Expand profiles in scriptlet context by
    @stgraber in #1504
- remove patches:
  * 0001-incusd-storage-zfs-Fix-deletion-of-unavailable-pools.patch
  * 0002-zfs-load-keys-for-encrypted-datasets-during-pool-imp.patch
* Fri Nov 22 2024 Aleksa Sarai <asarai@suse.com>
- Remove the incus.sysctl drop-in file. This setting file overlaps with lxd's
  sysctl settings, and setting these sysctls on boot even if you aren't running
  containers is suboptimal.
  We could come up with a complicated scheme for loading the rules once Incus
  starts, as suggested in bsc#1233410, but ultimately these settings are only
  really useful for production servers with >100 containers, at which point
  admins are expected to tune their servers anyway.
  So we can just remove it.
* Fri Nov 22 2024 Aleksa Sarai <asarai@suse.com>
- Backport patches to fix encrypted ZFS datasets having their keys be unloaded
  on Incus daemon restarts. <https://github.com/lxc/incus/pull/1384>
  + 0001-incusd-storage-zfs-Fix-deletion-of-unavailable-pools.patch
  + 0002-zfs-load-keys-for-encrypted-datasets-during-pool-imp.patch
* Thu Nov 21 2024 Charles Miller <charlesmillerspam@gmail.com>
- Fix secureboot VMs by switching to passing the correct environment variable
  (INCUS_EDK2_PATH) and updating the ovmf symlinks to point to the correct
  blobs. There is an upstream bug here, so we will need to fix this again later
  once <https://github.com/lxc/incus/pull/1406> is merged.
* Fri Nov 15 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 6.7:
  * fix live update VM's limits.memory configuration when use a percentage value #1287
  * fix: fix slice init length #1285
  * incusd/instance/lxc: Remove restrictions on /run #1288
  * Correct macvlan mode names #1284
  * Translations update from Hosted Weblate #1290
  * Translations update from Hosted Weblate #1295
  * Translations update from Hosted Weblate #1304
  * incus-simplestreams: Fix list -f json #1310
  * Profile performance improvements #1314
  * incus-agent: Add timeout for DNS query #1313
  * incusd/instance/qemu: Don't fail on console retrival issue #1316
  * Allow changing the parent value on physical networks #1317
  * incus: Fix display of current project in projects list #1318
  * Add --format to incus admin sql #1319
  * incusd/internal/server/instance/drivers: support for Chimera Linux (qemu/edk2) pkg layout #1298
  * incusd/instance/common: Cleanup volatile on device add failure #1323
  * incusd/network/bgp: Only advertise networks with BGP configuration #1325
  * Make revert library shared #1326
  * Fix to the cluster resources caching mechanism #1324
  * Fix idmap issues #1327
  * Make ask library shared #1329
  * doc/network/resolved: Add disabling DNSSEC and DNSOverTLS #1328
  * Add some application container documentation #1331
  * incusd/device/nic/bridged: Handle invalid configuration #1330
  * Fix handling of custom volume snapshot patterns #1333
  * Add OCI DHCP renewal #1334
  * doc/installing: Update for Chimera Linux #1335
  * shared/cgo: Don't use strlcpy #1337
  * Implement incus webui #1338
  * incusd/scriptlet: Make set_target fail with invalid members #1339
  * Export QMP functions #1340
  * incusd/network/ovn: Add support to ipv4.dhcp.ranges #1341
  * internal/server: Log QMP interaction to a file #1345
  * incusd/instance/qemu: Log QEMU command line #1346
  * Improve cluster instance placement #1344
  * incusd/instance_logs: Update log file list #1347
  * Add infrastructure for OVN events #1349
  * Fix QEMU feature checks during startup #1350
  * incusd/instance/lxc: Fix LXCFS per-instance path #1352
  * doc/idmap: Clarify subuid/subgid configuration #1353
  * incusd/instance/qmp: Fix logging with no log file #1355
  * Add a GetOIDCTokens() method #1357
  * Add get-current to show current project #1356
  * incus/file/create: Use SFTP client instead of file API #1354
  * internal/instance: Allow 0 as value to limits.cpu.nodes #1358
  * Translations update from Hosted Weblate #1361
  * Translations update from Hosted Weblate #1362
  * Translations update from Hosted Weblate #1368
  * Improve agent interface listing performance #1367
  * Make incus top output configurable through options #1370
  * Automatic live-migration to balance load on cluster #1369
  * gomod: Update dependencies #1372
  * Add refresh-exclude-older flag to only transfer new snapshots during instance/volume refresh #1365
  * incusd/instances/publish: Fix base metadata #1374
  * Fix TPM with long instance names #1377
  * Don't BGP advertise OVN load-balancers when all backends are offline #1376
  * incusd/instance/qemu: Don't take over operations on console retrieval #1379
  * Tweak to cluster internal relocation #1378
* Thu Nov 14 2024 Aleksa Sarai <asarai@suse.com>
- Move some binaries to sbin to match upstream packaging recommendations.
- Update VM-related dependencies to make VMs work properly.
* Wed Oct 23 2024 Aleksa Sarai <asarai@suse.com>
- Fix %%_libexecdir usage for Leap 15.x (Leap 15.x still uses /usr/lib, so we
  need to replace the usage of /usr/libexec in our scripts with a token that we
  can replace during build).
* Mon Oct 21 2024 Aleksa Sarai <asarai@suse.com>
- Rework packaging to match recommended packaging from doc/packaging.md and
  <https://github.com/zabbly/incus/tree/stable/systemd>.
* Fri Oct 18 2024 Aleksa Sarai <asarai@suse.com>
- Package Incus 6.6, based on the LXD 5.21 package. The primary differences are
  that we no longer need to do ELF patching to work around having a custom
  sqlite fork (instead we can use libcowsql, which is packaged for openSUSE
  already).
